@@ -5,15 +5,15 @@
 #' specified by the argument \code{model}, given specific parameter constellations.
 #' This function is a wrapper that calls the respective functions for diffusion based
 #' models (dynaViTE and 2DSD: \code{\link{simulateWEV}}) and race models (IRM, PCRM,
-#' IRMt, and PCRMt: \code{\link{simulateRM}}. It also computes the Gamma rank correlation
-#' between the confidence ratings and
+#' IRMt, and PCRMt: \code{\link{simulateRM}}; and MTLNR: \code{\link{simulateMTLNR}}).
+#' It also computes the Gamma rank correlation between the confidence ratings and
 #' condition (task difficulty), reaction times and accuracy in the simulated output.
 #'
 #' @param paramDf a list or dataframe with one row with the required parameters.
 #' @param n integer. The number of samples (per condition and stimulus direction) generated.
 #' Total number of samples is \code{n*nConditions*length(stimulus)}.
 #' @param model character scalar. One of "dynaViTE", "dynWEV", "2DSD", "2DSDT",
-#' "IRM", "PCRM", "IRMt", or "PCRMt". Could also be passed as a column in the paramDf argument.
+#' "IRM", "PCRM", "IRMt", "PCRMt", or "MTLNR". Could also be passed as a column in the paramDf argument.
 #' @param gamma logical. If TRUE, the gamma correlation between confidence ratings, rt and accuracy is
 #' computed.
 #' @param agg_simus logical. Simulation is done on a trial basis with RTs outcome. If TRUE,
@@ -52,9 +52,10 @@
 #' i.e. IRM(t) and PCRM(t), (\code{\link{simulateRM}}). See there for more information.
 #'
 #' \strong{Simulation Method:} The simulation is done by simulating normal variables
-#' in discretized steps until
-#' the processes reach the boundary. If no boundary is met within the maximum time,
-#' response is set to 0.
+#' in discretized steps until the processes reach the boundary.
+#' If no boundary is met within the maximum time, response is set to 0.
+#' The MTLNR model is simulated without discretization, but simply by simulating the
+#' necessary log-normally distributed random variables.
 #'
 #' \strong{Gamma correlations:} The Gamma coefficients are computed separately for
 #' correct/incorrect responses for the correlation of confidence ratings with condition and rt
@@ -114,6 +115,8 @@ simulateRTConf <- function (paramDf, n=1e+4,  model = NULL,
     }
   } else if (model %in% c("dynaViTE", "dynWEV", "2DSD", "2DSDT")) {
     res <- simulateWEV(paramDf, n, model, simult_conf, gamma, agg_simus, stimulus, delta=delta, maxrt=maxrt, seed=seed)
+  }else if (grepl("LNR",model)) {
+    res <- simulateMTLNR(paramDf, n, gamma, agg_simus, stimulus, seed=seed)
   } else {stop("model not known.")}
   return(res)
 }
